from PyQt6.QtWidgets import (QDialog, QVBoxLayout, QHBoxLayout,
                           QPushButton, QLabel, QLineEdit, QWidget,
                           QMessageBox)
from PyQt6.QtCore import Qt
from PyQt6.QtGui import QFont
from shiyunzi.utils.config_util import get_config, set_config
from shiyunzi.doubao.doubao_service import chat_completion
from shiyunzi.utils.log_util import get_logger
import os

logger = get_logger(__name__)
class DoubaoConfigDialog(QDialog):
    def __init__(self, parent=None):
        super().__init__(parent)
        self.setup_ui()
        self.load_config()
        
    def setup_ui(self):
        self.setWindowTitle("豆包配置")
        self.setFixedWidth(600)
        
        layout = QVBoxLayout(self)
        layout.setSpacing(20)
        
        # Cookie配置
        cookie_label = QLabel("Cookie:")
        cookie_label.setFont(QFont("Microsoft YaHei UI", 13))
        self.cookie_input = QLineEdit()
        self.cookie_input.setFont(QFont("Microsoft YaHei UI", 13))
        self.cookie_input.setStyleSheet("""
            QLineEdit {
                padding: 8px;
                border: 1px solid #e2e8f0;
                border-radius: 6px;
            }
            QLineEdit:focus {
                border-color: #6366f1;
            }
        """)
        layout.addWidget(cookie_label)
        layout.addWidget(self.cookie_input)
        
        # Device ID配置
        device_id_label = QLabel("Device ID:")
        device_id_label.setFont(QFont("Microsoft YaHei UI", 13))
        device_id_label.setStyleSheet("border: none;")
        self.device_id_input = QLineEdit()
        self.device_id_input.setFont(QFont("Microsoft YaHei UI", 13))
        self.device_id_input.setStyleSheet("""
            QLineEdit {
                padding: 8px;
                border: 1px solid #e2e8f0;
                border-radius: 6px;
            }
            QLineEdit:focus {
                border-color: #6366f1;
            }
        """)
        layout.addWidget(device_id_label)
        layout.addWidget(self.device_id_input)
        
        # Tea UUID配置
        tea_uuid_label = QLabel("Tea UUID:")
        tea_uuid_label.setFont(QFont("Microsoft YaHei UI", 13))
        tea_uuid_label.setStyleSheet("border: none;")
        self.tea_uuid_input = QLineEdit()
        self.tea_uuid_input.setFont(QFont("Microsoft YaHei UI", 13))
        self.tea_uuid_input.setStyleSheet("""
            QLineEdit {
                padding: 8px;
                border: 1px solid #e2e8f0;
                border-radius: 6px;
            }
            QLineEdit:focus {
                border-color: #6366f1;
            }
        """)
        layout.addWidget(tea_uuid_label)
        layout.addWidget(self.tea_uuid_input)
        
        # Web ID配置
        web_id_label = QLabel("Web ID:")
        web_id_label.setFont(QFont("Microsoft YaHei UI", 13))
        web_id_label.setStyleSheet("border: none;")
        self.web_id_input = QLineEdit()
        self.web_id_input.setFont(QFont("Microsoft YaHei UI", 13))
        self.web_id_input.setStyleSheet("""
            QLineEdit {
                padding: 8px;
                border: 1px solid #e2e8f0;
                border-radius: 6px;
            }
            QLineEdit:focus {
                border-color: #6366f1;
            }
        """)
        layout.addWidget(web_id_label)
        layout.addWidget(self.web_id_input)
        
        # Room ID配置
        room_id_label = QLabel("Room ID:")
        room_id_label.setFont(QFont("Microsoft YaHei UI", 13))
        room_id_label.setStyleSheet("border: none;")
        self.room_id_input = QLineEdit()
        self.room_id_input.setFont(QFont("Microsoft YaHei UI", 13))
        self.room_id_input.setStyleSheet("""
            QLineEdit {
                padding: 8px;
                border: 1px solid #e2e8f0;
                border-radius: 6px;
            }
            QLineEdit:focus {
                border-color: #6366f1;
            }
        """)
        layout.addWidget(room_id_label)
        layout.addWidget(self.room_id_input)
        
        # X Flow Trace配置
        x_flow_trace_label = QLabel("X Flow Trace:")
        x_flow_trace_label.setFont(QFont("Microsoft YaHei UI", 13))
        x_flow_trace_label.setStyleSheet("border: none;")
        self.x_flow_trace_input = QLineEdit()
        self.x_flow_trace_input.setFont(QFont("Microsoft YaHei UI", 13))
        self.x_flow_trace_input.setStyleSheet("""
            QLineEdit {
                padding: 8px;
                border: 1px solid #e2e8f0;
                border-radius: 6px;
            }
            QLineEdit:focus {
                border-color: #6366f1;
            }
        """)
        layout.addWidget(x_flow_trace_label)
        layout.addWidget(self.x_flow_trace_input)
        
        # 按钮容器
        button_container = QWidget()
        button_layout = QHBoxLayout(button_container)
        button_layout.setContentsMargins(0, 20, 0, 0)
        
        # 取消按钮
        cancel_btn = QPushButton("取消")
        cancel_btn.setFont(QFont("Microsoft YaHei UI", 13))
        cancel_btn.setCursor(Qt.CursorShape.PointingHandCursor)
        cancel_btn.setStyleSheet("""
            QPushButton {
                padding: 8px 20px;
                border: 1px solid #e2e8f0;
                border-radius: 6px;
                color: #64748b;
                background: white;
            }
            QPushButton:hover {
                background: #f8fafc;
                border-color: #cbd5e1;
            }
        """)
        cancel_btn.clicked.connect(self.reject)
        
        # 保存按钮
        save_btn = QPushButton("保存")
        save_btn.setFont(QFont("Microsoft YaHei UI", 13))
        save_btn.setCursor(Qt.CursorShape.PointingHandCursor)
        save_btn.setStyleSheet("""
            QPushButton {
                padding: 8px 20px;
                border: none;
                border-radius: 6px;
                color: white;
                background: #6366f1;
            }
            QPushButton:hover {
                background: #4f46e5;
            }
        """)
        save_btn.clicked.connect(self.save_config)
        
        button_layout.addWidget(cancel_btn)
        button_layout.addWidget(save_btn)
        
        layout.addWidget(button_container)
        
    def load_config(self):
        self.cookie_input.setText(get_config("doubao_cookie") or "")
        self.device_id_input.setText(get_config("doubao_device_id") or "")
        self.tea_uuid_input.setText(get_config("doubao_tea_uuid") or "")
        self.web_id_input.setText(get_config("doubao_web_id") or "")
        self.room_id_input.setText(get_config("doubao_room_id") or "")
        self.x_flow_trace_input.setText(get_config("doubao_x_flow_trace") or "")
        
    def save_config(self):
        set_config("doubao_cookie", self.cookie_input.text())
        set_config("doubao_device_id", self.device_id_input.text())
        set_config("doubao_tea_uuid", self.tea_uuid_input.text())
        set_config("doubao_web_id", self.web_id_input.text())
        set_config("doubao_room_id", self.room_id_input.text())
        set_config("doubao_x_flow_trace", self.x_flow_trace_input.text())
        
        # 显示提示弹窗
        msg_box = QMessageBox(self)
        msg_box.setWindowTitle("配置完成")
        msg_box.setText("豆包配置后需要重启脚本")
        msg_box.setIcon(QMessageBox.Icon.Information)
        msg_box.setStandardButtons(QMessageBox.StandardButton.Ok)
        msg_box.setFont(QFont("Microsoft YaHei UI", 13))
        msg_box.setStyleSheet("""
            QMessageBox {
                background-color: white;
            }
            QMessageBox QLabel {
                color: #1e293b;
                min-width: 200px;
            }
            QPushButton {
                padding: 8px 20px;
                border: none;
                border-radius: 6px;
                color: white;
                background: #6366f1;
                font-family: "Microsoft YaHei UI";
                font-size: 13px;
            }
            QPushButton:hover {
                background: #4f46e5;
            }
        """)
        
        # 当用户点击确定按钮时关闭脚本
        if msg_box.exec() == QMessageBox.StandardButton.Ok:
            os._exit(0) 
        